# Witter

## What's Witter?

Witter accepts text input, splits it into sections, or "chains", and then works out which character is most likely to follow that "chain" whenever it appears in the source text.

Once it has analyzed the source text, it generates a number of random sample pieces of text based on it.

Because of the way it uses the source text, the text that it produces will be "in the style" of the original text. It may, or may not, make sense.

It's worth noting that this isn't Machine Learning (ML), or any kind of Artificial Intelligence (AI). It's statistics, with some Monte Carlo methods thrown in.

## How Do I Use Witter?

Run `witter` from within a virtual environment using the syntax:

```python
witter --help
```

or from the command line using:

```python
python -m witter --help
```

Both of these examples will display the command line options.

A simple example to get you started is:

* download a large text file - perhaps [The Complete Works of Shakespeare from Project Gutenberg](https://www.gutenberg.org/ebooks/100)
* pass the contents of the file to `witter`

In Windows or Linux, in a Python virtual environment, the following command will produce samples:

```bash
witter filepath.txt
```

or, if you want to use piping in Linux:

```bash
cat filepath.txt | witter
```

So, if you want to generate text from The Complete Works of William Shakespeare, and why wouldn't you?

```bash
wget https://www.gutenberg.org/cache/epub/100/pg100.txt
cat pg100.txt | witter
```

or if A Christmas Carol by Charles Dickens is more your thing:

```bash
wget https://www.gutenberg.org/ebooks/24022.txt.utf-8
cat 24022.txt.utf-8 | witter
```

You've probably noticed the `utf-8` extension on one of the text files. This is a way that Project Gutenberg uses to denote UTF-8-encoded text files. `witter` can handle UTF-8 with no problems.

## Download Statistics
[![Downloads](https://static.pepy.tech/badge/witter)](https://pepy.tech/project/randalyze)
[![Downloads](https://static.pepy.tech/badge/witter/month)](https://pepy.tech/project/randalyze)
[![Downloads](https://static.pepy.tech/badge/witter/week)](https://pepy.tech/project/randalyze)
